==> haskell-colour-2.3.5-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.5
id: colour-2.3.5-EW05oj2CsGh4RFxrJSvKYT
key: colour-2.3.5-EW05oj2CsGh4RFxrJSvKYT
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
author: Russell O'\''Connor
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
abi: 013412a6b9bdd03424b0bd8fc163e24e
exposed: True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
import-dirs: /usr/lib/ghc-8.6.5/site-local/colour-2.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/colour-2.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-colour
hs-libraries: HScolour-2.3.5-EW05oj2CsGh4RFxrJSvKYT
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.5-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.5
id: colour-2.3.5-y0xjV3ONUd40VuBtReEvC
key: colour-2.3.5-y0xjV3ONUd40VuBtReEvC
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
author: Russell O'\''Connor
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
abi: ba8f53c96e2a45c83aa41ebf3ca192bb
exposed: True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
import-dirs: /usr/lib/ghc-8.6.5/site-local/colour-2.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/colour-2.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-colour
hs-libraries: HScolour-2.3.5-y0xjV3ONUd40VuBtReEvC
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
